deformation: Count points on hypersurfaces using the deformation method
=======================================================================

Description
-----------

Deformation is a C library for counting points on hypersurfaces using
the deformation method, developed by Sebastian Pancratz.

License
-------

GLPv3


Upstream Contact
----------------

-  Sebastian Pancratz: sebastian.pancratz@gmail.com, sage-devel@googlegroups.com

-  We use the fork at https://github.com/sagemath/deformation
   the fork uses GMP instead of MPIR, and Flint 2.7+.
